@@ -22,30 +22,64 @@ def main(request):
 def get(lst,index,default):
     if index<len(lst): return lst[index]
     return default
+
+def handle_dict(old_state,new_state,recursion=False):
+    res = ""
+    for key in old_state:
+        if key == "_type":
+            if old_state[key] == "datetime":
+                if datetime.datetime.strptime(old_state["value"], "%Y-%m-%d %H:%M:%S").strftime(
+                        "%Y-%m-%dT%H:%M:%SZ") != new_state:
+                    res += "<li> %s ----> %s</li>" % (old_state.get("value"), new_state)
+            elif old_state[key] == "date":
+                if datetime.datetime.strptime(old_state["value"], "%Y-%m-%d").strftime("%Y-%m-%d") != new_state:
+                    res += "<li> %s ----> %s</li>" % (old_state.get("value"), new_state)
+            break
+        elif new_state is None:
+            res += "<li> %s ----> NONE</li>" % (old_state.get(key))
+        elif old_state[key] != new_state.get(key, None):
+            if type(old_state[key]) in [type({}), type([])]:
+                try:
+                    c = findChanges(old_state.get(key, {}), new_state.get(key, {}))
+                    if c != "<ul></ul>":
+                        res += "<li>" + c + "</li>"
+                except:
+                    pass
+            else:
+                res += "<li>%s:: %s ----> %s</li>" % (key, old_state.get(key, None), new_state.get(key, None))
+    if recursion: return res
+    for key in new_state:
+        if key == "_type":
+            if new_state[key] == "datetime":
+                if datetime.datetime.strptime(old_state["value"], "%Y-%m-%d %H:%M:%S").strftime(
+                        "%Y-%m-%dT%H:%M:%SZ") != datetime.datetime.strptime(new_state["value"],
+                                                                            "%Y-%m-%d %H:%M:%S").strftime(
+                        "%Y-%m-%dT%H:%M:%SZ"):
+                    res += "<li> %s ----> %s</li>" % (old_state.get("value"), new_state)
+            elif old_state[key] == "date":
+                if datetime.datetime.strptime(old_state["value"], "%Y-%m-%d").strftime("%Y-%m-%d") != new_state:
+                    res += "<li> %s ----> %s</li>" % (old_state.get("value"), new_state)
+            break
+        elif old_state is None:
+            res += "<li> NONE ----> %s</li>" % (new_state.get(key))
+
+        elif new_state[key] != old_state.get(key, None):
+            if type(new_state[key]) in [type({}), type([])]:
+                try:
+                    c = findChanges(old_state.get(key, {}), new_state.get(key, {}), True)
+                    if c != "<ul></ul>":
+                        res += "<li>" + c + "</li>"
+
+                except:
+                    pass
+            else:
+                res += "<li>%s:: %s ----> %s</li>" % (key, old_state.get(key, None), new_state.get(key, None))
+    return res
+
 def findChanges(old_state,new_state):
     res="<ul>"
     if type(old_state)==type({}):
-        for key in old_state:
-            if key == "_type":
-                if old_state[key]=="datetime":
-                    if datetime.datetime.strptime(old_state["value"],"%Y-%m-%d %H:%M:%S").strftime("%Y-%m-%dT%H:%M:%SZ") != new_state:
-                        res += "<li> %s ----> %s</li>" % (old_state.get("value"), new_state)
-                elif old_state[key]=="date":
-                    if datetime.datetime.strptime(old_state["value"],"%Y-%m-%d").strftime("%Y-%m-%d") != new_state:
-                        res += "<li> %s ----> %s</li>" % (old_state.get("value"), new_state)
-                break
-            elif new_state is None:
-                res += "<li> %s ----> NONE</li>" % (old_state.get(key))
-            elif old_state[key]!=new_state.get(key,None):
-                if type(old_state[key]) in [type({}),type([])]:
-                    try:
-                        c = findChanges(old_state.get(key, {}), new_state.get(key, {}))
-                        if c!="<ul></ul>":
-                            res+= "<li>"+c+"</li>"
-                    except:
-                        pass
-                else:
-                    res+="<li>%s:: %s ----> %s</li>"%(key,old_state.get(key,None),new_state.get(key,None))
+        handle_dict(old_state,new_state)
     elif type(old_state)==type([]):
         for key in range(len(old_state)):
             if old_state[key] != get(new_state,key,None):
@@ -57,6 +91,8 @@ def findChanges(old_state,new_state):
                 else:
                     res += "<li>%s:: %s ----> %s</li>" % (key, old_state[key], get(new_state,key,None))
     return res+"</ul>"
+
+
 def fetchChanges(id,table):
     changes = History.objects.filter(primary_key=id, table=table).order_by("-id")
     rows = []
